@@ -11,7 +11,7 @@ It lets you create and edit charts, update your account information and many mor
 
         dw.account_info()
 """
-from typing import Any, Dict, Iterable, List, Union
+from typing import Any, Dict, Iterable, List, Optional, Union
 
 import json
 import os
@@ -126,6 +126,7 @@ class Datawrapper:
         chart_type: str = "d3-bars-stacked",
         data: Union[pd.DataFrame, None] = None,
         folder_id: str = "",
+        metadata: Optional[Dict[Any, Any]] = None,
     ) -> Union[Dict[Any, Any], None, Any]:
         """Creates a new Datawrapper chart, table or map.
         You can pass a pandas DataFrame as a `data` argument to upload data.
@@ -141,6 +142,8 @@ class Datawrapper:
             A pandas DataFrame containing the data to be added, by default None
         folder_id : str, optional
             ID of folder in Datawrapper.de for the chart, table or map to be created in, by default ""
+        metadata: dict, optional
+            A Python dictionary of properties to add.
 
         Returns
         -------
@@ -155,6 +158,8 @@ class Datawrapper:
 
         if folder_id:
             _data["folderId"] = folder_id
+        if metadata:
+            _data["metadata"] = metadata  # type: ignore
 
         new_chart_response = r.post(
             url=self._CHARTS_URL, headers=_header, data=json.dumps(_data)
@@ -604,6 +609,7 @@ class Datawrapper:
         search: str = "",
         order: str = "DESC",
         order_by: str = "createdAt",
+        folder_id: str = "",
         limit: int = 25,
     ) -> Union[None, List[Any]]:
         """Retrieves a list of charts by User
@@ -620,6 +626,8 @@ class Datawrapper:
             Result order (ascending or descending), by default "DESC"
         order_by : str, optional
             Attribute to order by. One of createdAt, email, id, or name, by default "createdAt"
+        folder_id: str, optional
+            ID of the folder to search charts in, by default ""
         limit : int, optional
             Maximum items to fetch, by default 25
 
@@ -643,6 +651,8 @@ class Datawrapper:
             _query["order"] = order
         if order_by:
             _query["orderBy"] = order_by
+        if folder_id:
+            _query["folderId"] = folder_id
         if limit:
             _query["limit"] = str(limit)
 
